#
# spec file for package mm-common
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2016 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mm-common
Version:        1.0.4
Release:        1.8
Summary:        Common build files of the GNOME C++ bindings
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://gtkmm.org
Source:         https://download.gnome.org/sources/%{name}/1.0/%{name}-%{version}.tar.xz
Source99:       mm-common-rpmlintrc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildArch:      noarch

%description
The mm-common module provides the build infrastructure and utilities
shared among the GNOME C++ binding libraries.  It is a required dependency
to build glibmm and gtkmm from git.

%package docs
Summary:        Documentation for %{name}, includes example mm module skeleton
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description docs
Package contains short documentation for %{name} and example skeleton module,
which could be used as a base for new mm module.

%prep
%autosetup -p1

# Remove executable bit in NEWS...
chmod -x NEWS

%build
%meson
%meson_build

%install
%meson_install

%files
%license COPYING
%doc NEWS AUTHORS README
%{_bindir}/mm-common-get
%{_bindir}/mm-common-prepare
%{_mandir}/man1/mm-common-get.1%{?ext_man}
%{_mandir}/man1/mm-common-prepare.1%{?ext_man}
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/mm-*.m4
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
# Not split out as the entire point of this package is development.
%{_datadir}/pkgconfig/mm-common-libstdc++.pc
%{_datadir}/pkgconfig/mm-common-util.pc

%files docs
%dir %{_datadir}/doc/%{name}
%{_datadir}/doc/mm-common/*

%changelog
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.4:
  + Add util/doc_postprocess.py and util/doc_install.py.
  + Generating documentation in modules that use mm-common does not
    require Perl in Meson builds.
  + Meson build and skeletonmm: Specify 'check' option in
    run_command(). The default value will change in future Meson
    releases.
- Changes from version 1.0.3:
  + Meson build:
  - Make it possible to use mm-common as a subproject
  - extra-install-cmd.py: Ignore FileNotFoundError
  - Make quiet installations possible
  + Skeletonmm:
  - Fix versioning on macOS
  - Use relative paths to untracked/
  - Update dependencies in Meson build files: glibmm-2.4 ->
    glibmm-2.68, sigc++-2.0 -> sigc++-3.0
  - Make it possible to use skeletonmm as a subproject
* Thu Mar  4 2021 Wang Jun <jgwang@suse.com>
- Update to version 1.0.2:
  * util/doc-install.pl: Update for Doxygen >= 1.8.16
    (Kjell Ahlstedt)
  * doc-reference.py: Don't include DESTDIR in the DevHelp base path
    (Kjell Ahlstedt) Issue #2 (Mart Raudsepp)
  * dist-build-scripts.py: Remove files from distribution, if requested
    (Kjell Ahlstedt)
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.1:
  + Make libstdc++.tag retrieval work for Windows
  + skeletonmm/meson.build: Check if .git is a directory or a file
  + util: Add check-dllexport-usage.py to check gmmproc version
  + skeletonmm: Improve the Meson build system
* Tue Oct 29 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.0:
  + Rename directory build/ to am_include/.
  + Add support for building mm-common with Meson.
  + Support modules that are built with Meson. Add the
    mm-common-get command.
  + skeletonmm: Use Meson instead of Autotools.
  + MM_AX_CXX_COMPILE_STDCXX(): Update based on the upstream
    AX_CXX_COMPILE_STDCXX() macro.
- Add meson BuildRequires and macros, following upstreams port.
* Thu Aug  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Own %%{_datadir}/aclocal: when we might switch to pkgconf instead
  of pkg-config, nothing in the build root is 'accidentally' owning
  this directory for us.
* Tue Apr 17 2018 jengelh@inai.de
- Update summaries.
* Sat Apr  7 2018 bjorn.lie@gmail.com
- Update to version 0.9.12:
  + MM_AX_CXX_COMPILE_STDCXX(): Update based on the upstream
    AX_CXX_COMPILE_STDCXX() macro, to support C++17.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Feb  4 2018 bjorn.lie@gmail.com
- Update to version 0.9.11:
  + Fix silent build (bgo#768797).
  + Build: don't save time stamps in skeletonmm.tar.gz
    (bgo#765108).
- Correct Group for docs sub package.
* Wed Aug 24 2016 zaitor@opensuse.org
- Initial package, version 0.9.10.
